@@ -20,6 +20,7 @@
 
 #include "oPRCFile.h"
 #include <time.h>
+#include <sstream>
 
 using std::string;
 
@@ -34,7 +35,7 @@ uint32_t PRCentity::getGraphicsIndex()
 void PRCline::writeRepresentationItem(PRCbitStream &out,uint32_t index)
 {
   out << (uint32_t)(PRC_TYPE_RI_Curve);
-  ContentPRCBase(&EMPTY_ATTRIBUTES,"line",true,makeCADID(),0,makePRCID()).write(out);
+  ContentPRCBase(&EMPTY_ATTRIBUTES,name,true,makeCADID(),0,makePRCID()).write(out);
   writeGraphics(out,m1,getGraphicsIndex(),1);
   out << (uint32_t)0 // index_local_coordinate_system+1
       << (uint32_t)0; // index_tessellation
@@ -102,7 +103,7 @@ void PRCline::writeExtraGeometryContext(PRCbitStream &out)
 void PRCcurve::writeRepresentationItem(PRCbitStream &out,uint32_t index)
 {
   out << (uint32_t)(PRC_TYPE_RI_Curve);
-  ContentPRCBase(&EMPTY_ATTRIBUTES,"curve",true,makeCADID(),0,makePRCID()).write(out);
+  ContentPRCBase(&EMPTY_ATTRIBUTES,name,true,makeCADID(),0,makePRCID()).write(out);
   writeGraphics(out,m1,getGraphicsIndex(),1);
   out << (uint32_t)0 // index_local_coordinate_system+1
       << (uint32_t)0; // index_tessellation
@@ -180,7 +181,7 @@ void PRCcurve::writeExtraGeometryContext(PRCbitStream &out)
 void PRCsurface::writeRepresentationItem(PRCbitStream &out,uint32_t index)
 {
   out << (uint32_t)(PRC_TYPE_RI_BrepModel);
-  ContentPRCBase(&EMPTY_ATTRIBUTES,"surface",true,makeCADID(),0,makePRCID()).write(out);
+  ContentPRCBase(&EMPTY_ATTRIBUTES,name,true,makeCADID(),0,makePRCID()).write(out);
   writeGraphics(out,0,getGraphicsIndex(),1);
   out << (uint32_t)0 // index_local_coordinate_system+1
       << (uint32_t)0; // index_tessellation
@@ -440,7 +441,7 @@ void PRCTreeSection::writeData()
   at.text = "__PRC_RESERVED_ATTRIBUTE_A3DF_ProductInformation";
   Attribute attr(false,at,3,sas);
   Attributes attrs(1,&attr);
-  ContentPRCBase(&attrs,"Unknown",true,makeCADID(),0,makePRCID()).write(out);
+  ContentPRCBase(&attrs,"root",true,makeCADID(),0,makePRCID()).write(out);
 
   writeGraphics(out,m1,m1,1,true);
   out << (uint32_t)1 // index_part+1
@@ -559,12 +560,12 @@ void makeAppUUID(uint32_t *UUID)
 
 void writeUINT32_T(std::ostream &out, uint32_t data)
 {
-#ifdef WORDS_BIG_ENDIAN
+#ifdef WORDS_BIGENDIAN
   out.write(((char*)&data)+3,1);
   out.write(((char*)&data)+2,1);
   out.write(((char*)&data)+1,1);
   out.write(((char*)&data)+0,1);
-#elif WORDS_LITTLE_ENDIAN
+#else
   out.write(((char*)&data)+0,1);
   out.write(((char*)&data)+1,1);
   out.write(((char*)&data)+2,1);
